==> google_cloud_dataplex-2.2.2.tar.gz: google_cloud_dataplex-2.2.2/google/cloud/dataplex_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .analyze import Content, Environment, Session
from .catalog import (
    Aspect,
    AspectSource,
    AspectType,
    CreateAspectTypeRequest,
    CreateEntryGroupRequest,
    CreateEntryRequest,
    CreateEntryTypeRequest,
    DeleteAspectTypeRequest,
    DeleteEntryGroupRequest,
    DeleteEntryRequest,
    DeleteEntryTypeRequest,
    Entry,
    EntryGroup,
    EntrySource,
    EntryType,
    EntryView,
    GetAspectTypeRequest,
    GetEntryGroupRequest,
    GetEntryRequest,
    GetEntryTypeRequest,
    ListAspectTypesRequest,
    ListAspectTypesResponse,
    ListEntriesRequest,
    ListEntriesResponse,
    ListEntryGroupsRequest,
    ListEntryGroupsResponse,
    ListEntryTypesRequest,
    ListEntryTypesResponse,
    LookupEntryRequest,
    SearchEntriesRequest,
    SearchEntriesResponse,
    SearchEntriesResult,
    TransferStatus,
    UpdateAspectTypeRequest,
    UpdateEntryGroupRequest,
    UpdateEntryRequest,
    UpdateEntryTypeRequest,
)
from .content import (
    CreateContentRequest,
    DeleteContentRequest,
    GetContentRequest,
    ListContentRequest,
    ListContentResponse,
    UpdateContentRequest,
)
from .data_profile import DataProfileResult, DataProfileSpec
from .data_quality import (
    DataQualityColumnResult,
    DataQualityDimension,
    DataQualityDimensionResult,
    DataQualityResult,
    DataQualityRule,
    DataQualityRuleResult,
    DataQualitySpec,
)
from .data_taxonomy import (
    CreateDataAttributeBindingRequest,
    CreateDataAttributeRequest,
    CreateDataTaxonomyRequest,
    DataAttribute,
    DataAttributeBinding,
    DataTaxonomy,
    DeleteDataAttributeBindingRequest,
    DeleteDataAttributeRequest,
    DeleteDataTaxonomyRequest,
    GetDataAttributeBindingRequest,
    GetDataAttributeRequest,
    GetDataTaxonomyRequest,
    ListDataAttributeBindingsRequest,
    ListDataAttributeBindingsResponse,
    ListDataAttributesRequest,
    ListDataAttributesResponse,
    ListDataTaxonomiesRequest,
    ListDataTaxonomiesResponse,
    UpdateDataAttributeBindingRequest,
    UpdateDataAttributeRequest,
    UpdateDataTaxonomyRequest,
)
from .datascans import (
    CreateDataScanRequest,
    DataScan,
    DataScanJob,
    DataScanType,
    DeleteDataScanRequest,
    GenerateDataQualityRulesRequest,
    GenerateDataQualityRulesResponse,
    GetDataScanJobRequest,
    GetDataScanRequest,
    ListDataScanJobsRequest,
    ListDataScanJobsResponse,
    ListDataScansRequest,
    ListDataScansResponse,
    RunDataScanRequest,
    RunDataScanResponse,
    UpdateDataScanRequest,
)
from .logs import (
    DataQualityScanRuleResult,
    DataScanEvent,
    DiscoveryEvent,
    GovernanceEvent,
    JobEvent,
    SessionEvent,
)
from .metadata_ import (
    CreateEntityRequest,
    CreatePartitionRequest,
    DeleteEntityRequest,
    DeletePartitionRequest,
    Entity,
    GetEntityRequest,
    GetPartitionRequest,
    ListEntitiesRequest,
    ListEntitiesResponse,
    ListPartitionsRequest,
    ListPartitionsResponse,
    Partition,
    Schema,
    StorageAccess,
    StorageFormat,
    StorageSystem,
    UpdateEntityRequest,
)
from .processing import DataSource, ScannedData, Trigger
from .resources import Action, Asset, AssetStatus, Lake, State, Zone
from .security import DataAccessSpec, ResourceAccessSpec
from .service import (
    CancelJobRequest,
    CreateAssetRequest,
    CreateEnvironmentRequest,
    CreateLakeRequest,
    CreateTaskRequest,
    CreateZoneRequest,
    DeleteAssetRequest,
    DeleteEnvironmentRequest,
    DeleteLakeRequest,
    DeleteTaskRequest,
    DeleteZoneRequest,
    GetAssetRequest,
    GetEnvironmentRequest,
    GetJobRequest,
    GetLakeRequest,
    GetTaskRequest,
    GetZoneRequest,
    ListActionsResponse,
    ListAssetActionsRequest,
    ListAssetsRequest,
    ListAssetsResponse,
    ListEnvironmentsRequest,
    ListEnvironmentsResponse,
    ListJobsRequest,
    ListJobsResponse,
    ListLakeActionsRequest,
    ListLakesRequest,
    ListLakesResponse,
    ListSessionsRequest,
    ListSessionsResponse,
    ListTasksRequest,
    ListTasksResponse,
    ListZoneActionsRequest,
    ListZonesRequest,
    ListZonesResponse,
    OperationMetadata,
    RunTaskRequest,
    RunTaskResponse,
    UpdateAssetRequest,
    UpdateEnvironmentRequest,
    UpdateLakeRequest,
    UpdateTaskRequest,
    UpdateZoneRequest,
)
from .tasks import Job, Task

__all__ = (
    "Content",
    "Environment",
    "Session",
    "Aspect",
    "AspectSource",
    "AspectType",
    "CreateAspectTypeRequest",
    "CreateEntryGroupRequest",
    "CreateEntryRequest",
    "CreateEntryTypeRequest",
    "DeleteAspectTypeRequest",
    "DeleteEntryGroupRequest",
    "DeleteEntryRequest",
    "DeleteEntryTypeRequest",
    "Entry",
    "EntryGroup",
    "EntrySource",
    "EntryType",
    "GetAspectTypeRequest",
    "GetEntryGroupRequest",
    "GetEntryRequest",
    "GetEntryTypeRequest",
    "ListAspectTypesRequest",
    "ListAspectTypesResponse",
    "ListEntriesRequest",
    "ListEntriesResponse",
    "ListEntryGroupsRequest",
    "ListEntryGroupsResponse",
    "ListEntryTypesRequest",
    "ListEntryTypesResponse",
    "LookupEntryRequest",
    "SearchEntriesRequest",
    "SearchEntriesResponse",
    "SearchEntriesResult",
    "UpdateAspectTypeRequest",
    "UpdateEntryGroupRequest",
    "UpdateEntryRequest",
    "UpdateEntryTypeRequest",
    "EntryView",
    "TransferStatus",
    "CreateContentRequest",
    "DeleteContentRequest",
    "GetContentRequest",
    "ListContentRequest",
    "ListContentResponse",
    "UpdateContentRequest",
    "DataProfileResult",
    "DataProfileSpec",
    "DataQualityColumnResult",
    "DataQualityDimension",
    "DataQualityDimensionResult",
    "DataQualityResult",
    "DataQualityRule",
    "DataQualityRuleResult",
    "DataQualitySpec",
    "CreateDataAttributeBindingRequest",
    "CreateDataAttributeRequest",
    "CreateDataTaxonomyRequest",
    "DataAttribute",
    "DataAttributeBinding",
    "DataTaxonomy",
    "DeleteDataAttributeBindingRequest",
    "DeleteDataAttributeRequest",
    "DeleteDataTaxonomyRequest",
    "GetDataAttributeBindingRequest",
    "GetDataAttributeRequest",
    "GetDataTaxonomyRequest",
    "ListDataAttributeBindingsRequest",
    "ListDataAttributeBindingsResponse",
    "ListDataAttributesRequest",
    "ListDataAttributesResponse",
    "ListDataTaxonomiesRequest",
    "ListDataTaxonomiesResponse",
    "UpdateDataAttributeBindingRequest",
    "UpdateDataAttributeRequest",
    "UpdateDataTaxonomyRequest",
    "CreateDataScanRequest",
    "DataScan",
    "DataScanJob",
    "DeleteDataScanRequest",
    "GenerateDataQualityRulesRequest",
    "GenerateDataQualityRulesResponse",
    "GetDataScanJobRequest",
    "GetDataScanRequest",
    "ListDataScanJobsRequest",
    "ListDataScanJobsResponse",
    "ListDataScansRequest",
    "ListDataScansResponse",
    "RunDataScanRequest",
    "RunDataScanResponse",
    "UpdateDataScanRequest",
    "DataScanType",
    "DataQualityScanRuleResult",
    "DataScanEvent",
    "DiscoveryEvent",
    "GovernanceEvent",
    "JobEvent",
    "SessionEvent",
    "CreateEntityRequest",
    "CreatePartitionRequest",
    "DeleteEntityRequest",
    "DeletePartitionRequest",
    "Entity",
    "GetEntityRequest",
    "GetPartitionRequest",
    "ListEntitiesRequest",
    "ListEntitiesResponse",
    "ListPartitionsRequest",
    "ListPartitionsResponse",
    "Partition",
    "Schema",
    "StorageAccess",
    "StorageFormat",
    "UpdateEntityRequest",
    "StorageSystem",
    "DataSource",
    "ScannedData",
    "Trigger",
    "Action",
    "Asset",
    "AssetStatus",
    "Lake",
    "Zone",
    "State",
    "DataAccessSpec",
    "ResourceAccessSpec",
    "CancelJobRequest",
    "CreateAssetRequest",
    "CreateEnvironmentRequest",
    "CreateLakeRequest",
    "CreateTaskRequest",
    "CreateZoneRequest",
    "DeleteAssetRequest",
    "DeleteEnvironmentRequest",
    "DeleteLakeRequest",
    "DeleteTaskRequest",
    "DeleteZoneRequest",
    "GetAssetRequest",
    "GetEnvironmentRequest",
    "GetJobRequest",
    "GetLakeRequest",
    "GetTaskRequest",
    "GetZoneRequest",
    "ListActionsResponse",
    "ListAssetActionsRequest",
    "ListAssetsRequest",
    "ListAssetsResponse",
    "ListEnvironmentsRequest",
    "ListEnvironmentsResponse",
    "ListJobsRequest",
    "ListJobsResponse",
    "ListLakeActionsRequest",
    "ListLakesRequest",
    "ListLakesResponse",
    "ListSessionsRequest",
    "ListSessionsResponse",
    "ListTasksRequest",
    "ListTasksResponse",
    "ListZoneActionsRequest",
    "ListZonesRequest",
    "ListZonesResponse",
    "OperationMetadata",
    "RunTaskRequest",
    "RunTaskResponse",
    "UpdateAssetRequest",
    "UpdateEnvironmentRequest",
    "UpdateLakeRequest",
    "UpdateTaskRequest",
    "UpdateZoneRequest",
    "Job",
    "Task",
)

==> google_cloud_dataplex-2.11.0.tar.gz: google_cloud_dataplex-2.11.0/google/cloud/dataplex_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .analyze import Content, Environment, Session
from .catalog import (
    Aspect,
    AspectSource,
    AspectType,
    CancelMetadataJobRequest,
    CreateAspectTypeRequest,
    CreateEntryGroupRequest,
    CreateEntryRequest,
    CreateEntryTypeRequest,
    CreateMetadataJobRequest,
    DeleteAspectTypeRequest,
    DeleteEntryGroupRequest,
    DeleteEntryRequest,
    DeleteEntryTypeRequest,
    Entry,
    EntryGroup,
    EntrySource,
    EntryType,
    EntryView,
    GetAspectTypeRequest,
    GetEntryGroupRequest,
    GetEntryRequest,
    GetEntryTypeRequest,
    GetMetadataJobRequest,
    ImportItem,
    ListAspectTypesRequest,
    ListAspectTypesResponse,
    ListEntriesRequest,
    ListEntriesResponse,
    ListEntryGroupsRequest,
    ListEntryGroupsResponse,
    ListEntryTypesRequest,
    ListEntryTypesResponse,
    ListMetadataJobsRequest,
    ListMetadataJobsResponse,
    LookupEntryRequest,
    MetadataJob,
    SearchEntriesRequest,
    SearchEntriesResponse,
    SearchEntriesResult,
    TransferStatus,
    UpdateAspectTypeRequest,
    UpdateEntryGroupRequest,
    UpdateEntryRequest,
    UpdateEntryTypeRequest,
)
from .cmek import (
    CreateEncryptionConfigRequest,
    DeleteEncryptionConfigRequest,
    EncryptionConfig,
    GetEncryptionConfigRequest,
    ListEncryptionConfigsRequest,
    ListEncryptionConfigsResponse,
    UpdateEncryptionConfigRequest,
)
from .content import (
    CreateContentRequest,
    DeleteContentRequest,
    GetContentRequest,
    ListContentRequest,
    ListContentResponse,
    UpdateContentRequest,
)
from .data_discovery import DataDiscoveryResult, DataDiscoverySpec
from .data_profile import DataProfileResult, DataProfileSpec
from .data_quality import (
    DataQualityColumnResult,
    DataQualityDimension,
    DataQualityDimensionResult,
    DataQualityResult,
    DataQualityRule,
    DataQualityRuleResult,
    DataQualitySpec,
)
from .data_taxonomy import (
    CreateDataAttributeBindingRequest,
    CreateDataAttributeRequest,
    CreateDataTaxonomyRequest,
    DataAttribute,
    DataAttributeBinding,
    DataTaxonomy,
    DeleteDataAttributeBindingRequest,
    DeleteDataAttributeRequest,
    DeleteDataTaxonomyRequest,
    GetDataAttributeBindingRequest,
    GetDataAttributeRequest,
    GetDataTaxonomyRequest,
    ListDataAttributeBindingsRequest,
    ListDataAttributeBindingsResponse,
    ListDataAttributesRequest,
    ListDataAttributesResponse,
    ListDataTaxonomiesRequest,
    ListDataTaxonomiesResponse,
    UpdateDataAttributeBindingRequest,
    UpdateDataAttributeRequest,
    UpdateDataTaxonomyRequest,
)
from .datascans import (
    CreateDataScanRequest,
    DataScan,
    DataScanJob,
    DataScanType,
    DeleteDataScanRequest,
    GenerateDataQualityRulesRequest,
    GenerateDataQualityRulesResponse,
    GetDataScanJobRequest,
    GetDataScanRequest,
    ListDataScanJobsRequest,
    ListDataScanJobsResponse,
    ListDataScansRequest,
    ListDataScansResponse,
    RunDataScanRequest,
    RunDataScanResponse,
    UpdateDataScanRequest,
)
from .logs import (
    BusinessGlossaryEvent,
    DataQualityScanRuleResult,
    DataScanEvent,
    DiscoveryEvent,
    EntryLinkEvent,
    GovernanceEvent,
    JobEvent,
    SessionEvent,
)
from .metadata_ import (
    CreateEntityRequest,
    CreatePartitionRequest,
    DeleteEntityRequest,
    DeletePartitionRequest,
    Entity,
    GetEntityRequest,
    GetPartitionRequest,
    ListEntitiesRequest,
    ListEntitiesResponse,
    ListPartitionsRequest,
    ListPartitionsResponse,
    Partition,
    Schema,
    StorageAccess,
    StorageFormat,
    StorageSystem,
    UpdateEntityRequest,
)
from .processing import DataSource, ScannedData, Trigger
from .resources import Action, Asset, AssetStatus, Lake, State, Zone
from .security import DataAccessSpec, ResourceAccessSpec
from .service import (
    CancelJobRequest,
    CreateAssetRequest,
    CreateEnvironmentRequest,
    CreateLakeRequest,
    CreateTaskRequest,
    CreateZoneRequest,
    DeleteAssetRequest,
    DeleteEnvironmentRequest,
    DeleteLakeRequest,
    DeleteTaskRequest,
    DeleteZoneRequest,
    GetAssetRequest,
    GetEnvironmentRequest,
    GetJobRequest,
    GetLakeRequest,
    GetTaskRequest,
    GetZoneRequest,
    ListActionsResponse,
    ListAssetActionsRequest,
    ListAssetsRequest,
    ListAssetsResponse,
    ListEnvironmentsRequest,
    ListEnvironmentsResponse,
    ListJobsRequest,
    ListJobsResponse,
    ListLakeActionsRequest,
    ListLakesRequest,
    ListLakesResponse,
    ListSessionsRequest,
    ListSessionsResponse,
    ListTasksRequest,
    ListTasksResponse,
    ListZoneActionsRequest,
    ListZonesRequest,
    ListZonesResponse,
    OperationMetadata,
    RunTaskRequest,
    RunTaskResponse,
    UpdateAssetRequest,
    UpdateEnvironmentRequest,
    UpdateLakeRequest,
    UpdateTaskRequest,
    UpdateZoneRequest,
)
from .tasks import Job, Task

__all__ = (
    "Content",
    "Environment",
    "Session",
    "Aspect",
    "AspectSource",
    "AspectType",
    "CancelMetadataJobRequest",
    "CreateAspectTypeRequest",
    "CreateEntryGroupRequest",
    "CreateEntryRequest",
    "CreateEntryTypeRequest",
    "CreateMetadataJobRequest",
    "DeleteAspectTypeRequest",
    "DeleteEntryGroupRequest",
    "DeleteEntryRequest",
    "DeleteEntryTypeRequest",
    "Entry",
    "EntryGroup",
    "EntrySource",
    "EntryType",
    "GetAspectTypeRequest",
    "GetEntryGroupRequest",
    "GetEntryRequest",
    "GetEntryTypeRequest",
    "GetMetadataJobRequest",
    "ImportItem",
    "ListAspectTypesRequest",
    "ListAspectTypesResponse",
    "ListEntriesRequest",
    "ListEntriesResponse",
    "ListEntryGroupsRequest",
    "ListEntryGroupsResponse",
    "ListEntryTypesRequest",
    "ListEntryTypesResponse",
    "ListMetadataJobsRequest",
    "ListMetadataJobsResponse",
    "LookupEntryRequest",
    "MetadataJob",
    "SearchEntriesRequest",
    "SearchEntriesResponse",
    "SearchEntriesResult",
    "UpdateAspectTypeRequest",
    "UpdateEntryGroupRequest",
    "UpdateEntryRequest",
    "UpdateEntryTypeRequest",
    "EntryView",
    "TransferStatus",
    "CreateEncryptionConfigRequest",
    "DeleteEncryptionConfigRequest",
    "EncryptionConfig",
    "GetEncryptionConfigRequest",
    "ListEncryptionConfigsRequest",
    "ListEncryptionConfigsResponse",
    "UpdateEncryptionConfigRequest",
    "CreateContentRequest",
    "DeleteContentRequest",
    "GetContentRequest",
    "ListContentRequest",
    "ListContentResponse",
    "UpdateContentRequest",
    "DataDiscoveryResult",
    "DataDiscoverySpec",
    "DataProfileResult",
    "DataProfileSpec",
    "DataQualityColumnResult",
    "DataQualityDimension",
    "DataQualityDimensionResult",
    "DataQualityResult",
    "DataQualityRule",
    "DataQualityRuleResult",
    "DataQualitySpec",
    "CreateDataAttributeBindingRequest",
    "CreateDataAttributeRequest",
    "CreateDataTaxonomyRequest",
    "DataAttribute",
    "DataAttributeBinding",
    "DataTaxonomy",
    "DeleteDataAttributeBindingRequest",
    "DeleteDataAttributeRequest",
    "DeleteDataTaxonomyRequest",
    "GetDataAttributeBindingRequest",
    "GetDataAttributeRequest",
    "GetDataTaxonomyRequest",
    "ListDataAttributeBindingsRequest",
    "ListDataAttributeBindingsResponse",
    "ListDataAttributesRequest",
    "ListDataAttributesResponse",
    "ListDataTaxonomiesRequest",
    "ListDataTaxonomiesResponse",
    "UpdateDataAttributeBindingRequest",
    "UpdateDataAttributeRequest",
    "UpdateDataTaxonomyRequest",
    "CreateDataScanRequest",
    "DataScan",
    "DataScanJob",
    "DeleteDataScanRequest",
    "GenerateDataQualityRulesRequest",
    "GenerateDataQualityRulesResponse",
    "GetDataScanJobRequest",
    "GetDataScanRequest",
    "ListDataScanJobsRequest",
    "ListDataScanJobsResponse",
    "ListDataScansRequest",
    "ListDataScansResponse",
    "RunDataScanRequest",
    "RunDataScanResponse",
    "UpdateDataScanRequest",
    "DataScanType",
    "BusinessGlossaryEvent",
    "DataQualityScanRuleResult",
    "DataScanEvent",
    "DiscoveryEvent",
    "EntryLinkEvent",
    "GovernanceEvent",
    "JobEvent",
    "SessionEvent",
    "CreateEntityRequest",
    "CreatePartitionRequest",
    "DeleteEntityRequest",
    "DeletePartitionRequest",
    "Entity",
    "GetEntityRequest",
    "GetPartitionRequest",
    "ListEntitiesRequest",
    "ListEntitiesResponse",
    "ListPartitionsRequest",
    "ListPartitionsResponse",
    "Partition",
    "Schema",
    "StorageAccess",
    "StorageFormat",
    "UpdateEntityRequest",
    "StorageSystem",
    "DataSource",
    "ScannedData",
    "Trigger",
    "Action",
    "Asset",
    "AssetStatus",
    "Lake",
    "Zone",
    "State",
    "DataAccessSpec",
    "ResourceAccessSpec",
    "CancelJobRequest",
    "CreateAssetRequest",
    "CreateEnvironmentRequest",
    "CreateLakeRequest",
    "CreateTaskRequest",
    "CreateZoneRequest",
    "DeleteAssetRequest",
    "DeleteEnvironmentRequest",
    "DeleteLakeRequest",
    "DeleteTaskRequest",
    "DeleteZoneRequest",
    "GetAssetRequest",
    "GetEnvironmentRequest",
    "GetJobRequest",
    "GetLakeRequest",
    "GetTaskRequest",
    "GetZoneRequest",
    "ListActionsResponse",
    "ListAssetActionsRequest",
    "ListAssetsRequest",
    "ListAssetsResponse",
    "ListEnvironmentsRequest",
    "ListEnvironmentsResponse",
    "ListJobsRequest",
    "ListJobsResponse",
    "ListLakeActionsRequest",
    "ListLakesRequest",
    "ListLakesResponse",
    "ListSessionsRequest",
    "ListSessionsResponse",
    "ListTasksRequest",
    "ListTasksResponse",
    "ListZoneActionsRequest",
    "ListZonesRequest",
    "ListZonesResponse",
    "OperationMetadata",
    "RunTaskRequest",
    "RunTaskResponse",
    "UpdateAssetRequest",
    "UpdateEnvironmentRequest",
    "UpdateLakeRequest",
    "UpdateTaskRequest",
    "UpdateZoneRequest",
    "Job",
    "Task",
)
